% Compute an optimal numbering of the finite element nodes using an
% appropriate method. The numbering may  be then passed to
% renum_mesh_renumber() to renumber the mesh.
% 
% function numbering=renum_mesh_numbering(fens, gcells, method)
% 
% fens, gcells = arrays of finite element nodes and geometric cells
% method =  either 'symrcm' or 'symamd' (optional argument, default
%           'symrcm') 
%     
function numbering=renum_mesh_numbering(fens, gcells, method)
    if (~exist('method','var'))
        method ='symrcm';
    end
    
    conns = gcells_to_conns(gcells);
    A=conn_to_sparse(conns);
    if (strcmp(method,'symrcm'))
        % Reverse Cuthill-McKee
        p=symrcm(A);
    elseif (strcmp(method,'symamd'))
        p=symamd(A);
    else
        eval(['p=' method '(A);']);
    end
    
    ip=(1:length(p));
    ip(p)=(1:length(p));
    numbering.p =p;
    numbering.ip =ip;
end
